/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */
#define PW_IP_PORT_LIMIT_INFO 241.5
#define PW_IP_PORT_RANGE 241.6
#define PW_IP_PORT_FORWARDING_MAP 241.7
#define PW_IP_PORT_TYPE 241.5.1
#define PW_IP_PORT_LIMIT 241.5.2
#define PW_IP_PORT_EXT_IPV4_ADDR 241.5.3
#define PW_IP_PORT_INT_IPV4_ADDR 241.5.4
#define PW_IP_PORT_INT_IPV6_ADDR 241.5.5
#define PW_IP_PORT_INT_PORT 241.5.6
#define PW_IP_PORT_EXT_PORT 241.5.7
#define PW_IP_PORT_ALLOC 241.5.8
#define PW_IP_PORT_RANGE_START 241.5.9
#define PW_IP_PORT_RANGE_END 241.5.10
#define PW_IP_PORT_LOCAL_ID 241.5.11
#define PW_IP_PORT_RANGE_TYPE 241.6.1
#define PW_IP_PORT_RANGE_LIMIT 241.6.2
#define PW_IP_PORT_RANGE_EXT_IPV4_ADDR 241.6.3
#define PW_IP_PORT_RANGE_INT_IPV4_ADDR 241.6.4
#define PW_IP_PORT_RANGE_INT_IPV6_ADDR 241.6.5
#define PW_IP_PORT_RANGE_INT_PORT 241.6.6
#define PW_IP_PORT_RANGE_EXT_PORT 241.6.7
#define PW_IP_PORT_RANGE_ALLOC 241.6.8
#define PW_IP_PORT_RANGE_RANGE_START 241.6.9
#define PW_IP_PORT_RANGE_RANGE_END 241.6.10
#define PW_IP_PORT_RANGE_LOCAL_ID 241.6.11
#define PW_IP_PORT_MAP_TYPE 241.7.1
#define PW_IP_PORT_MAP_LIMIT 241.7.2
#define PW_IP_PORT_MAP_EXT_IPV4_ADDR 241.7.3
#define PW_IP_PORT_MAP_INT_IPV4_ADDR 241.7.4
#define PW_IP_PORT_MAP_INT_IPV6_ADDR 241.7.5
#define PW_IP_PORT_MAP_INT_PORT 241.7.6
#define PW_IP_PORT_MAP_EXT_PORT 241.7.7
#define PW_IP_PORT_MAP_ALLOC 241.7.8
#define PW_IP_PORT_MAP_RANGE_START 241.7.9
#define PW_IP_PORT_MAP_RANGE_END 241.7.10
#define PW_IP_PORT_MAP_LOCAL_ID 241.7.11
