/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */
#define PW_OPERATOR_NAME 126
#define PW_LOCATION_INFORMATION 127
#define PW_LOCATION_DATA 128
#define PW_BASIC_LOCATION_POLICY_RULES 129
#define PW_EXTENDED_LOCATION_POLICY_RULES 130
#define PW_LOCATION_CAPABLE 131
#define PW_REQUESTED_LOCATION_INFO 132
