/* Automatically generated by "build-radpaths-h" */
#define LOGDIR		"/var/log/radius"
#define LIBDIR		"/usr/local/lib/freeradius"
#define RADDBDIR	"/etc/raddb"
#define RUNDIR		"/var/run"
#define SBINDIR		"/usr/local/sbin"
#define RADIR		"/var/log/radius/radacct"
#define DICTDIR		"/usr/local/share/freeradius"
