/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */
#define PW_DIGEST_RESPONSE 103
#define PW_DIGEST_REALM 104
#define PW_DIGEST_NONCE 105
#define PW_DIGEST_RESPONSE_AUTH 106
#define PW_DIGEST_NEXTNONCE 107
#define PW_DIGEST_METHOD 108
#define PW_DIGEST_URI 109
#define PW_DIGEST_QOP 110
#define PW_DIGEST_ALGORITHM 111
#define PW_DIGEST_ENTITY_BODY_HASH 112
#define PW_DIGEST_CNONCE 113
#define PW_DIGEST_NONCE_COUNT 114
#define PW_DIGEST_USERNAME 115
#define PW_DIGEST_OPAQUE 116
#define PW_DIGEST_AUTH_PARAM 117
#define PW_DIGEST_AKA_AUTS 118
#define PW_DIGEST_DOMAIN 119
#define PW_DIGEST_STALE 120
#define PW_DIGEST_HA1 121
#define PW_SIP_AOR 122
