/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */
#define PW_EXTENDED_ATTRIBUTE_1 241
#define PW_EXTENDED_ATTRIBUTE_2 242
#define PW_EXTENDED_ATTRIBUTE_3 243
#define PW_EXTENDED_ATTRIBUTE_4 244
#define PW_EXTENDED_ATTRIBUTE_5 245
#define PW_EXTENDED_ATTRIBUTE_6 246
#define PW_EXTENDED_VENDOR_SPECIFIC_1 241.26
#define PW_EXTENDED_VENDOR_SPECIFIC_2 242.26
#define PW_EXTENDED_VENDOR_SPECIFIC_3 243.26
#define PW_EXTENDED_VENDOR_SPECIFIC_4 244.26
#define PW_EXTENDED_VENDOR_SPECIFIC_5 245.26
#define PW_EXTENDED_VENDOR_SPECIFIC_6 246.26
