/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */
#define PW_FREERADIUS_PROXIED_TO 1
#define PW_FREERADIUS_ACCT_SESSION_START_TIME 2
#define PW_FREERADIUS_STATISTICS_TYPE 127
#define PW_FREERADIUS_TOTAL_ACCESS_REQUESTS 128
#define PW_FREERADIUS_TOTAL_ACCESS_ACCEPTS 129
#define PW_FREERADIUS_TOTAL_ACCESS_REJECTS 130
#define PW_FREERADIUS_TOTAL_ACCESS_CHALLENGES 131
#define PW_FREERADIUS_TOTAL_AUTH_RESPONSES 132
#define PW_FREERADIUS_TOTAL_AUTH_DUPLICATE_REQUESTS 133
#define PW_FREERADIUS_TOTAL_AUTH_MALFORMED_REQUESTS 134
#define PW_FREERADIUS_TOTAL_AUTH_INVALID_REQUESTS 135
#define PW_FREERADIUS_TOTAL_AUTH_DROPPED_REQUESTS 136
#define PW_FREERADIUS_TOTAL_AUTH_UNKNOWN_TYPES 137
#define PW_FREERADIUS_TOTAL_PROXY_ACCESS_REQUESTS 138
#define PW_FREERADIUS_TOTAL_PROXY_ACCESS_ACCEPTS 139
#define PW_FREERADIUS_TOTAL_PROXY_ACCESS_REJECTS 140
#define PW_FREERADIUS_TOTAL_PROXY_ACCESS_CHALLENGES 141
#define PW_FREERADIUS_TOTAL_PROXY_AUTH_RESPONSES 142
#define PW_FREERADIUS_TOTAL_PROXY_AUTH_DUPLICATE_REQUESTS 143
#define PW_FREERADIUS_TOTAL_PROXY_AUTH_MALFORMED_REQUESTS 144
#define PW_FREERADIUS_TOTAL_PROXY_AUTH_INVALID_REQUESTS 145
#define PW_FREERADIUS_TOTAL_PROXY_AUTH_DROPPED_REQUESTS 146
#define PW_FREERADIUS_TOTAL_PROXY_AUTH_UNKNOWN_TYPES 147
#define PW_FREERADIUS_TOTAL_ACCOUNTING_REQUESTS 148
#define PW_FREERADIUS_TOTAL_ACCOUNTING_RESPONSES 149
#define PW_FREERADIUS_TOTAL_ACCT_DUPLICATE_REQUESTS 150
#define PW_FREERADIUS_TOTAL_ACCT_MALFORMED_REQUESTS 151
#define PW_FREERADIUS_TOTAL_ACCT_INVALID_REQUESTS 152
#define PW_FREERADIUS_TOTAL_ACCT_DROPPED_REQUESTS 153
#define PW_FREERADIUS_TOTAL_ACCT_UNKNOWN_TYPES 154
#define PW_FREERADIUS_TOTAL_PROXY_ACCOUNTING_REQUESTS 155
#define PW_FREERADIUS_TOTAL_PROXY_ACCOUNTING_RESPONSES 156
#define PW_FREERADIUS_TOTAL_PROXY_ACCT_DUPLICATE_REQUESTS 157
#define PW_FREERADIUS_TOTAL_PROXY_ACCT_MALFORMED_REQUESTS 158
#define PW_FREERADIUS_TOTAL_PROXY_ACCT_INVALID_REQUESTS 159
#define PW_FREERADIUS_TOTAL_PROXY_ACCT_DROPPED_REQUESTS 160
#define PW_FREERADIUS_TOTAL_PROXY_ACCT_UNKNOWN_TYPES 161
#define PW_FREERADIUS_QUEUE_LEN_INTERNAL 162
#define PW_FREERADIUS_QUEUE_LEN_PROXY 163
#define PW_FREERADIUS_QUEUE_LEN_AUTH 164
#define PW_FREERADIUS_QUEUE_LEN_ACCT 165
#define PW_FREERADIUS_QUEUE_LEN_DETAIL 166
#define PW_FREERADIUS_STATS_CLIENT_IP_ADDRESS 167
#define PW_FREERADIUS_STATS_CLIENT_NUMBER 168
#define PW_FREERADIUS_STATS_CLIENT_NETMASK 169
#define PW_FREERADIUS_STATS_SERVER_IP_ADDRESS 170
#define PW_FREERADIUS_STATS_SERVER_PORT 171
#define PW_FREERADIUS_STATS_SERVER_OUTSTANDING_REQUESTS 172
#define PW_FREERADIUS_STATS_SERVER_STATE 173
#define PW_FREERADIUS_STATS_SERVER_TIME_OF_DEATH 174
#define PW_FREERADIUS_STATS_SERVER_TIME_OF_LIFE 175
#define PW_FREERADIUS_STATS_START_TIME 176
#define PW_FREERADIUS_STATS_HUP_TIME 177
#define PW_FREERADIUS_SERVER_EMA_WINDOW 178
#define PW_FREERADIUS_SERVER_EMA_USEC_WINDOW_1 179
#define PW_FREERADIUS_SERVER_EMA_USEC_WINDOW_10 180
#define PW_FREERADIUS_QUEUE_PPS_IN 181
#define PW_FREERADIUS_QUEUE_PPS_OUT 182
#define PW_FREERADIUS_QUEUE_USE_PERCENTAGE 183
#define PW_FREERADIUS_STATS_LAST_PACKET_RECV 184
#define PW_FREERADIUS_STATS_LAST_PACKET_SENT 185
#define PW_FREERADIUS_EAP_FAST_TLV 186
#define PW_FREERADIUS_EAP_FAST_RESULT 186.3
#define PW_FREERADIUS_EAP_FAST_NAK 186.4
#define PW_FREERADIUS_EAP_FAST_ERROR 186.5
#define PW_FREERADIUS_EAP_FAST_VENDOR_SPECIFIC 186.7
#define PW_FREERADIUS_EAP_FAST_EAP_PAYLOAD 186.9
#define PW_FREERADIUS_EAP_FAST_INTERMEDIATE_RESULT 186.10
#define PW_FREERADIUS_EAP_FAST_PAC 186.11
#define PW_FREERADIUS_EAP_FAST_PAC_KEY 186.11.1
#define PW_FREERADIUS_EAP_FAST_PAC_OPAQUE_TLV 186.11.2
#define PW_FREERADIUS_EAP_FAST_PAC_OPAQUE_PAC_KEY 186.11.2.1
#define PW_FREERADIUS_EAP_FAST_PAC_OPAQUE_PAC_LIFETIME 186.11.2.3
#define PW_FREERADIUS_EAP_FAST_PAC_OPAQUE_I_ID 186.11.2.5
#define PW_FREERADIUS_EAP_FAST_PAC_OPAQUE_PAC_TYPE 186.11.2.10
#define PW_FREERADIUS_EAP_FAST_PAC_LIFETIME 186.11.3
#define PW_FREERADIUS_EAP_FAST_PAC_A_ID 186.11.4
#define PW_FREERADIUS_EAP_FAST_PAC_I_ID 186.11.5
#define PW_FREERADIUS_EAP_FAST_PAC_A_ID_INFO 186.11.7
#define PW_FREERADIUS_EAP_FAST_PAC_ACKNOWLEDGE 186.11.8
#define PW_FREERADIUS_EAP_FAST_PAC_INFO_TLV 186.11.9
#define PW_FREERADIUS_EAP_FAST_PAC_INFO_PAC_LIFETIME 186.11.9.3
#define PW_FREERADIUS_EAP_FAST_PAC_INFO_A_ID 186.11.9.4
#define PW_FREERADIUS_EAP_FAST_PAC_INFO_I_ID 186.11.9.5
#define PW_FREERADIUS_EAP_FAST_PAC_INFO_A_ID_INFO 186.11.9.7
#define PW_FREERADIUS_EAP_FAST_PAC_INFO_PAC_TYPE 186.11.9.10
#define PW_FREERADIUS_EAP_FAST_PAC_TYPE 186.11.10
#define PW_FREERADIUS_EAP_FAST_CRYPTO_BINDING 186.12
#define PW_FREERADIUS_EAP_FAST_TRUSTED_ROOT 186.18
#define PW_FREERADIUS_EAP_FAST_REQUEST_ACTION 186.19
#define PW_FREERADIUS_EAP_FAST_PKCS 186.20
#define PW_FREERADIUS_STATS_ERROR 187
#define PW_FREERADIUS_STATS_CLIENT_IPV6_ADDRESS 188
#define PW_FREERADIUS_STATS_SERVER_IPV6_ADDRESS 189
