/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */
#define PW_PKM_SS_CERT 137
#define PW_PKM_CA_CERT 138
#define PW_PKM_CONFIG_SETTINGS 139
#define PW_PKM_CRYPTOSUITE_LIST 140
#define PW_PKM_SAID 141
#define PW_PKM_SA_DESCRIPTOR 142
#define PW_PKM_AUTH_KEY 143
