/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */
#define PW_FRAMED_MANAGEMENT 133
#define PW_MANAGEMENT_TRANSPORT_PROTECTION 134
#define PW_MANAGEMENT_POLICY_ID 135
#define PW_MANAGEMENT_PRIVILEGE_LEVEL 136
